@@ -284,6 +284,8 @@ inline constexpr char16_t kInvalidAboutPageExpectRelativePath[] =
 inline constexpr char kInvalidAction[] = "Invalid value for 'action'.";
 inline constexpr char16_t kInvalidActionDefaultIcon[] =
     u"Invalid value for 'default_icon'.";
+inline constexpr char kInvalidActionDefaultIconMimeType[] =
+    "Invalid mime type for 'default_icon'.";
 inline constexpr char16_t kInvalidActionDefaultPopup[] =
     u"Invalid type for 'default_popup'.";
 inline constexpr char16_t kInvalidActionDefaultState[] =
@@ -301,6 +303,10 @@ inline constexpr char kInvalidBackgroundScript[] =
     "Invalid value for 'background.scripts[*]'.";
 inline constexpr char16_t kInvalidBackgroundScripts[] =
     u"Invalid value for 'background.scripts'.";
+inline constexpr char kInvalidBackgroundScriptMimeType[] =
+    "Invalid background script mime type for 'background.scripts[*]', a "
+    "background script can only be loaded from supported JavaScript files such "
+    "as .js files.";
 inline constexpr char16_t kInvalidBackgroundServiceWorkerScript[] =
     u"Invalid value for 'background.service_worker'.";
 inline constexpr char16_t kInvalidBackgroundServiceWorkerType[] =
@@ -411,6 +417,8 @@ inline constexpr char kInvalidHostPermission[] = "Invalid value for '*[*]'.";
 inline constexpr char kInvalidHostPermissions[] = "Invalid value for '*'.";
 inline constexpr char kInvalidIconKey[] = "Invalid key in icons: \"*\".";
 inline constexpr char kInvalidIconPath[] = "Invalid value for 'icons[\"*\"]'.";
+inline constexpr char kInvalidIconMimeType[] =
+    "Invalid mime type for 'icons[\"*\"]'.";
 inline constexpr char16_t kInvalidIcons[] = u"Invalid value for 'icons'.";
 inline constexpr char16_t kInvalidImportAndExport[] =
     u"Simultaneous 'import' and 'export' are not allowed.";
@@ -496,6 +504,8 @@ inline constexpr char kInvalidMatchCount[] =
     "one match specified.";
 inline constexpr char kInvalidMatches[] =
     "Required value 'content_scripts[*].matches' is missing or invalid.";
+inline constexpr char kInvalidUserScriptMimeType[] =
+    "Invalid script mime type: '%s'";
 inline constexpr char16_t kInvalidMIMETypes[] =
     u"Invalid value for 'mime_types'";
 inline constexpr char16_t kInvalidMimeTypesHandler[] =
@@ -563,6 +573,12 @@ inline constexpr char16_t kInvalidThemeColors[] =
     u"Invalid value for theme colors - colors must be integers";
 inline constexpr char16_t kInvalidThemeImages[] =
     u"Invalid value for theme images - images must be strings.";
+inline constexpr char kInvalidThemeImageMimeType[] =
+    "Invalid mime type for theme image '*'.";
+inline constexpr char kThemeImageMissingFileExtension[] =
+    "A file name extension is missing for theme image '*'. The image is "
+    "accepted for compatibility reasons, but such images might become "
+    "unsupported in the future.";
 inline constexpr char kInvalidThemeImagesMissing[] =
     "An image specified in the theme is missing.";
 inline constexpr char16_t kInvalidThemeTints[] =
