@@ -477,6 +477,18 @@ GURL SimplifyUrlForRequest(const GURL& url) {
   return url.ReplaceComponents(replacements);
 }
 
+GURL RemoveCredentialsFromUrl(const GURL& url) {
+  DCHECK(url.is_valid());
+  // Fast path to avoid re-canonicalization via ReplaceComponents.
+  if (!url.has_username() && !url.has_password()) {
+    return url;
+  }
+  GURL::Replacements replacements;
+  replacements.ClearUsername();
+  replacements.ClearPassword();
+  return url.ReplaceComponents(replacements);
+}
+
 GURL ChangeWebSocketSchemeToHttpScheme(const GURL& url) {
   DCHECK(url.SchemeIsWSOrWSS());
   GURL::Replacements replace_scheme;
