@@ -304,9 +304,10 @@ LoadStateWithParam URLRequest::GetLoadState() const {
                             std::u16string());
 }
 
-base::Value::Dict URLRequest::GetStateAsValue() const {
+base::Value::Dict URLRequest::GetStateAsValue(
+    NetLogCaptureMode capture_mode) const {
   base::Value::Dict dict;
-  dict.Set("url", original_url().possibly_invalid_spec());
+  dict.Set("url", SanitizeUrlForNetLog(original_url(), capture_mode));
 
   if (url_chain_.size() > 1) {
     base::Value::List list;
@@ -635,10 +636,11 @@ URLRequest::URLRequest(base::PassKey<URLRequestContext> pass_key,
   DCHECK(base::SingleThreadTaskRunner::HasCurrentDefault());
 
   context->url_requests()->insert(this);
-  net_log_.BeginEvent(NetLogEventType::REQUEST_ALIVE, [&] {
-    return NetLogURLRequestConstructorParams(url, priority_,
-                                             traffic_annotation_);
-  });
+  net_log_.BeginEvent(NetLogEventType::REQUEST_ALIVE,
+                      [&](NetLogCaptureMode capture_mode) {
+                        return NetLogURLRequestConstructorParams(
+                            url, priority_, traffic_annotation_, capture_mode);
+                      });
 }
 
 void URLRequest::BeforeRequestComplete(int error) {
@@ -676,12 +678,15 @@ void URLRequest::StartJob(std::unique_ptr<URLRequestJob> job) {
     DCHECK(!allow_credentials_);
   }
 
-  net_log_.BeginEvent(NetLogEventType::URL_REQUEST_START_JOB, [&] {
-    return NetLogURLRequestStartParams(
-        url(), method_, load_flags(), isolation_info_, site_for_cookies_,
-        initiator_,
-        upload_data_stream_ ? upload_data_stream_->identifier() : -1);
-  });
+  net_log_.BeginEvent(
+      NetLogEventType::URL_REQUEST_START_JOB,
+      [&](NetLogCaptureMode capture_mode) {
+        return NetLogURLRequestStartParams(
+            url(), method_, load_flags(), isolation_info_, site_for_cookies_,
+            initiator_,
+            upload_data_stream_ ? upload_data_stream_->identifier() : -1,
+            capture_mode);
+      });
 
   job_ = std::move(job);
   job_->SetExtraRequestHeaders(extra_request_headers_);
