@@ -37,6 +37,7 @@ public:
 #endif
 
     bool isReady() const;
+    bool CanFireEvents() const override;
 
     QtWebEngineCore::BrowserAccessibilityInterface *interface = nullptr;
 };
@@ -163,6 +164,13 @@ bool BrowserAccessibilityQt::isReady() const
     return manager()->GetFromID(node()->id()) != nullptr;
 }
 
+bool BrowserAccessibilityQt::CanFireEvents() const
+{
+    if (!node() || !interface || !isReady())
+        return false;
+    return BrowserAccessibility::CanFireEvents();
+}
+
 #if defined(Q_OS_MACOS)
 
 // Mac-only logic based on ui/accessibility/platform/browser_accessibility_mac.mm:
