@@ -4,8 +4,6 @@
 
 #include "content_client_qt.h"
 
-#include "compositor/compositor.h"
-
 #include "base/command_line.h"
 #include "base/files/file_util.h"
 #include "base/json/json_string_value_serializer.h"
@@ -13,15 +11,11 @@
 #include "base/strings/string_util.h"
 #include "base/values.h"
 #include "base/version.h"
-#include "content/gpu/gpu_child_thread.h"
 #include "content/public/common/cdm_info.h"
 #include "content/public/common/content_constants.h"
 #include "content/public/common/content_switches.h"
 #include "extensions/buildflags/buildflags.h"
 #include "extensions/common/constants.h"
-#include "gpu/config/gpu_feature_info.h"
-#include "gpu/config/gpu_preferences.h"
-#include "gpu/ipc/service/gpu_channel_manager.h"
 #include "media/base/media_switches.h"
 #include "media/base/video_codecs.h"
 #include "media/cdm/supported_audio_codecs.h"
@@ -34,10 +28,8 @@
 #include <QCoreApplication>
 #include <QFile>
 #include <QLibraryInfo>
-#include <QRegularExpression>
 #include <QString>
 #include <QSysInfo>
-#include <QThread>
 
 #if BUILDFLAG(IS_WIN)
 #include "ui/gl/gl_utils.h"
@@ -497,165 +489,4 @@ blink::OriginTrialPolicy *ContentClientQt::GetOriginTrialPolicy()
     return origin_trial_policy_.get();
 }
 
-void ContentClientQt::SetGpuInfo(const gpu::GPUInfo &gpu_info)
-{
-    base::CommandLine *commandLine = base::CommandLine::ForCurrentProcess();
-    const bool isBrowserProcess = !commandLine->HasSwitch(switches::kProcessType);
-    const bool isMainThread = QThread::currentThread() == qApp->thread();
-
-    // Limit this to the main thread of the browser process for now.
-    if (!isBrowserProcess || !isMainThread)
-        return;
-
-    if (!gpu_info.IsInitialized()) {
-        // This is probably not an issue but suspicious.
-        qWarning("Failed to initialize GPUInfo.");
-        return;
-    }
-
-    const gpu::GPUInfo::GPUDevice &primary = gpu_info.gpu;
-
-    // Do not print the info again if the device hasn't been changed.
-    // Change of the device is unexpected: we don't support or implement fallback yet.
-    // It is suspicious if the info is logged twice.
-    if (m_gpuInfo && m_gpuInfo->gpu.device_string == primary.device_string)
-        return;
-    m_gpuInfo = gpu_info;
-
-    auto *gpuChannelManager = content::GpuChildThread::instance()->gpu_channel_manager();
-    const gpu::GpuFeatureStatus gpuCompositingStatus =
-            gpuChannelManager->gpu_feature_info()
-                    .status_values[gpu::GPU_FEATURE_TYPE_ACCELERATED_GL];
-
-#if BUILDFLAG(IS_OZONE)
-    if (gpuCompositingStatus == gpu::kGpuFeatureStatusEnabled) {
-        // See entry 3 in //gpu/config/software_rendering_list.json
-        QRegularExpression filter(u"software|llvmpipe|softpipe"_s,
-                                  QRegularExpression::CaseInsensitiveOption);
-        if (filter.match(QLatin1StringView(gpu_info.gl_renderer)).hasMatch()) {
-            qWarning("Hardware rendering is enabled but it is not supported with Mesa software "
-                     "rasterizer. Expect troubles.");
-
-            if (gpuChannelManager->gpu_preferences().ignore_gpu_blocklist)
-                qWarning("Rendering may fail because --ignore-gpu-blocklist is set.");
-        }
-    }
-#endif
-
-    if (Q_LIKELY(!lcWebEngineCompositor().isDebugEnabled()))
-        return;
-
-    auto deviceToString = [](const gpu::GPUInfo::GPUDevice &device) -> QString {
-        if (device.vendor_id == 0x0)
-            return "Disabled"_L1;
-
-        QString log;
-
-        // TODO: Factor vendor translation out from QtWebEngineCore::GPUInfo.
-        // Only name the most common desktop GPU hardware vendors for now.
-        switch (device.vendor_id) {
-        case 0x1002:
-            log += "AMD"_L1;
-            break;
-        case 0x10DE:
-            log += "Nvidia"_L1;
-            break;
-        case 0x8086:
-            log += "Intel"_L1;
-            break;
-        default:
-            log += "vendor id: 0x"_L1 + QString::number(device.vendor_id, 16);
-        }
-
-        log += ", device id: 0x"_L1 + QString::number(device.device_id, 16);
-
-        if (!device.driver_vendor.empty()) {
-            log += ", driver: "_L1 + QLatin1StringView(device.driver_vendor) + u' '
-                    + QLatin1StringView(device.driver_version);
-        }
-        log += ", system device id: 0x"_L1 + QString::number(device.system_device_id, 16);
-
-        log += ", preference: "_L1;
-        switch (device.gpu_preference) {
-        case gl::GpuPreference::kNone:
-            log += "None"_L1;
-            break;
-        case gl::GpuPreference::kDefault:
-            log += "Default"_L1;
-            break;
-        case gl::GpuPreference::kLowPower:
-            log += "LowPower"_L1;
-            break;
-        case gl::GpuPreference::kHighPerformance:
-            log += "HighPerformance"_L1;
-            break;
-        }
-
-        log += ", active: "_L1 + (device.active ? "yes"_L1 : "no"_L1);
-        return log;
-    };
-
-    QString log;
-
-    log = "GPU Compositing: ";
-    switch (gpuCompositingStatus) {
-    case gpu::kGpuFeatureStatusEnabled:
-        log += "Enabled"_L1;
-        break;
-    case gpu::kGpuFeatureStatusBlocklisted:
-        log += "Blocklisted"_L1;
-        break;
-    case gpu::kGpuFeatureStatusDisabled:
-        log += "Disabled"_L1;
-        break;
-    case gpu::kGpuFeatureStatusSoftware:
-        log += "Software"_L1;
-        break;
-    case gpu::kGpuFeatureStatusUndefined:
-        log += "Undefined"_L1;
-        break;
-    case gpu::kGpuFeatureStatusMax:
-        log += "Max"_L1;
-        break;
-    }
-    qCDebug(lcWebEngineCompositor, "%ls", qUtf16Printable(log));
-
-    if (gpu_info.gl_vendor.empty() || gpu_info.gl_vendor == "Disabled") {
-        log = "ANGLE is disabled:\n"_L1;
-        log += "  GL Renderer: "_L1 + QLatin1StringView(gpu_info.gl_renderer) + u'\n';
-        log += "  Software Renderer: "_L1 + (primary.IsSoftwareRenderer() ? "yes"_L1 : "no"_L1)
-                + u'\n';
-        log += "  Primary GPU: "_L1 + deviceToString(primary) + u'\n';
-    } else {
-        log = QLatin1StringView(gpu_info.display_type) + " display is initialized:\n"_L1;
-        log += "  GL Renderer: "_L1 + QLatin1StringView(gpu_info.gl_renderer) + u'\n';
-        log += "  "_L1 + QString::number(gpu_info.GpuCount()) + " GPU(s) detected:\n"_L1;
-        log += "    "_L1 + deviceToString(primary) + u'\n';
-        for (auto &secondary : gpu_info.secondary_gpus)
-            log += "    "_L1 + deviceToString(secondary) + u'\n';
-
-        log += "  NVIDIA Optimus: "_L1 + (gpu_info.optimus ? "enabled"_L1 : "disabled"_L1) + u'\n';
-        log += "  AMD Switchable: "_L1 + (gpu_info.amd_switchable ? "enabled"_L1 : "disabled"_L1);
-    }
-
-    qCDebug(lcWebEngineCompositor, "%ls", qUtf16Printable(log));
-
-#if BUILDFLAG(IS_WIN)
-    log = "Windows specific driver information:\n"_L1;
-
-    log += "  Direct Composition: "_L1;
-    if (gpu_info.overlay_info.direct_composition)
-        log += "enabled\n"_L1;
-    else if (gl::GetGlWorkarounds().disable_direct_composition)
-        log += "disabled by workaround\n"_L1;
-    else
-        log += "disabled\n"_L1;
-
-    log += "  Supports Overlays: "_L1
-            + (gpu_info.overlay_info.supports_overlays ? "yes"_L1 : "no"_L1) + u'\n';
-    log += "  Supports D3D Shared Images: "_L1 + (gpu_info.shared_image_d3d ? "yes"_L1 : "no"_L1);
-    qCDebug(lcWebEngineCompositor, "%ls", qUtf16Printable(log));
-#endif
-}
-
 } // namespace QtWebEngineCore
