@@ -194,6 +194,12 @@ content::ContentBrowserClient *ContentMainDelegateQt::CreateContentBrowserClient
     return m_browserClient.get();
 }
 
+content::ContentGpuClient *ContentMainDelegateQt::CreateContentGpuClient()
+{
+    m_gpuClient.reset(new ContentGpuClientQt);
+    return m_gpuClient.get();
+}
+
 content::ContentRendererClient *ContentMainDelegateQt::CreateContentRendererClient()
 {
 #if BUILDFLAG(IS_LINUX)
