@@ -1,5 +1,6 @@
 // Copyright (C) 2016 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
+// Qt-Security score:significant reason:default
 
 #include "profile_adapter.h"
 
@@ -95,22 +96,32 @@ ProfileAdapter::ProfileAdapter(const QString &storageName, const QString &dataPa
                                const QString &cachePath, HttpCacheType httpCacheType,
                                PersistentCookiesPolicy persistentCookiesPolicy,
                                int httpCacheMaximumSize,
-                               PersistentPermissionsPolicy persistentPermissionPolicy,
-                               const QList<QSslCertificate> &additionalTrustedCertificates)
+                               PersistentPermissionsPolicy persistentPermissionPolicy
+#if QT_CONFIG(ssl)
+                               ,
+                               const QList<QSslCertificate> &additionalTrustedCertificates
+#endif
+                               )
     : m_name(storageName)
     , m_offTheRecord(storageName.isEmpty())
-    , m_dataPath(dataPath.isEmpty() && !m_name.isEmpty() ? buildLocationFromStandardPath(
-                         QStandardPaths::writableLocation(QStandardPaths::AppDataLocation), m_name)
-                                                         : dataPath)
+    , m_dataPath(dataPath.isEmpty() && !m_name.isEmpty()
+                         ? buildLocationFromStandardPath(QStandardPaths::writableLocation(
+                                                                 QStandardPaths::AppDataLocation),
+                                                         m_name)
+                         : dataPath)
     , m_downloadPath(QStandardPaths::writableLocation(QStandardPaths::DownloadLocation))
-    , m_cachePath(cachePath.isEmpty() && !m_name.isEmpty() ? buildLocationFromStandardPath(
-                          QStandardPaths::writableLocation(QStandardPaths::CacheLocation), m_name)
-                                                           : cachePath)
+    , m_cachePath(cachePath.isEmpty() && !m_name.isEmpty()
+                          ? buildLocationFromStandardPath(
+                                    QStandardPaths::writableLocation(QStandardPaths::CacheLocation),
+                                    m_name)
+                          : cachePath)
     , m_httpCacheType(httpCacheType)
     , m_persistentCookiesPolicy(persistentCookiesPolicy)
     , m_persistentPermissionsPolicy(persistentPermissionPolicy)
     , m_visitedLinksPolicy(TrackVisitedLinksOnDisk)
+#if QT_CONFIG(ssl)
     , m_additionalTrustedCertificates(additionalTrustedCertificates)
+#endif
     , m_clientHintsEnabled(true)
     , m_pushServiceEnabled(false)
     , m_httpCacheMaxSize(m_name.isEmpty() ? 0 : httpCacheMaximumSize)
@@ -887,7 +898,7 @@ void ProfileAdapter::reinitializeHistoryService()
 {
     Q_ASSERT(!m_offTheRecord);
     if (ensureDataPathExists()) {
-        // remove the associated services first, so we can get new ones (inited with
+        // remove the associated services first, so we can get new ones (initialized with
         // the new data paths) from the factory
         FaviconServiceFactoryQt::RemoveFromBrowserContext(m_profile.data());
         HistoryServiceFactoryQt::RemoveFromBrowserContext(m_profile.data());
@@ -937,12 +948,12 @@ QWebEngineClientCertificateStore *ProfileAdapter::clientCertificateStore()
         m_clientCertificateStore = new QWebEngineClientCertificateStore(m_profile->m_profileIOData->clientCertificateStoreData());
     return m_clientCertificateStore;
 }
-#endif
 
 QList<QSslCertificate> ProfileAdapter::additionalTrustedCertificates() const
 {
     return m_additionalTrustedCertificates;
 }
+#endif
 
 static void callbackOnIconAvailableForPageURL(std::function<void (const QIcon &, const QUrl &, const QUrl &)> iconAvailableCallback,
                                               const QUrl &pageUrl,
