@@ -55,19 +55,30 @@ void RenderWidgetHostViewQtDelegateItem::initAsPopup(const QRect &screenRect)
 {
     Q_ASSERT(m_isPopup);
     setSize(screenRect.size());
+    m_popupRect = screenRect;
     if (m_widgetDelegate)
         m_widgetDelegate->InitAsPopup(screenRect);
 }
 
 QRectF RenderWidgetHostViewQtDelegateItem::viewGeometry() const
 {
-    // Transform the entire rect to find the correct top left corner.
-    const QPointF p1 = mapToGlobal(mapFromItem(this, QPointF(0, 0)));
-    const QPointF p2 = mapToGlobal(mapFromItem(this, QPointF(width(), height())));
-    QRectF geometry = QRectF(p1, p2).normalized();
-    // But keep the size untransformed to behave like other QQuickItems.
-    geometry.setSize(size());
-    return geometry;
+    const QTransform transform = itemTransform(nullptr, nullptr);
+
+    const bool isTransformed = transform.type() > QTransform::TxTranslate;
+
+    if (!isTransformed) {
+        // find the correct top left corner
+        const QPointF tl = mapToGlobal(QPointF(0, 0));
+        return QRectF(tl, size());
+    } else if (!m_isPopup) {
+        // keep it simply untransformed, as we transform only delegate as there no way
+        // to return screen rect which would makes sense in that case
+        // this is just band-aid workaround to support rotation and scaling
+        return QRectF(QPointF(0, 0), size());
+    } else {
+        // this is transformed and popup, keep chromium unaware of transformations
+        return m_popupRect;
+    }
 }
 
 QRect RenderWidgetHostViewQtDelegateItem::windowGeometry() const
@@ -321,7 +332,7 @@ void RenderWidgetHostViewQtDelegateItem::inputMethodEvent(QInputMethodEvent *eve
 void RenderWidgetHostViewQtDelegateItem::geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry)
 {
     QQuickItem::geometryChange(newGeometry, oldGeometry);
-    m_client->visualPropertiesChanged();
+    polish();
 }
 
 void RenderWidgetHostViewQtDelegateItem::itemChange(ItemChange change, const ItemChangeData &value)
@@ -352,7 +363,7 @@ void RenderWidgetHostViewQtDelegateItem::itemChange(ItemChange change, const Ite
             if (!m_isPopup)
                 m_windowConnections.append(connect(value.window, SIGNAL(closing(QQuickCloseEvent*)), SLOT(onHide())));
         }
-        m_client->visualPropertiesChanged();
+        polish();
     } else if (change == QQuickItem::ItemVisibleHasChanged) {
         if (value.boolValue) {
             m_client->notifyShown();
@@ -364,58 +375,69 @@ void RenderWidgetHostViewQtDelegateItem::itemChange(ItemChange change, const Ite
                 onHide();
         }
     } else if (change == QQuickItem::ItemDevicePixelRatioHasChanged) {
-        m_client->visualPropertiesChanged();
+        polish();
     }
 }
 
 class CleanupJob : public QRunnable
 {
 public:
-    CleanupJob(Compositor::Handle<Compositor> compositor) : m_compositor(std::move(compositor)) { }
-
-    ~CleanupJob()
+    CleanupJob(Compositor::Observer *o) : m_observer(o)
     {
-        if (m_compositor->hasResources()) {
-            qWarning("Failed to release graphics resources because the clean-up render job was "
-                     "deleted.");
-        }
+        // Note this assumes observer and compositor calls unbind in destructor
+        o->lockForRelease();
     }
 
-    void run() override { m_compositor->releaseResources(); }
-
-private:
-    Compositor::Handle<Compositor> m_compositor;
+    ~CleanupJob() override
+    {
+        {
+            auto comp = m_observer->compositor();
+            Q_ASSERT(comp && !comp->hasResources());
+        }
+        m_observer->unlockForRelease();
+    }
+    void run() override
+    {
+        auto comp = m_observer->compositor();
+        Q_ASSERT(comp);
+        comp->releaseResources();
+    }
+    Compositor::Observer *m_observer;
 };
 
 void RenderWidgetHostViewQtDelegateItem::releaseResources()
 {
-    auto comp = compositor();
-    if (!comp || comp->type() != Compositor::Type::Native || !comp->hasResources())
-        return;
+    {
+        auto comp = compositor();
+        if (!comp || comp->type() != Compositor::Type::Native || !comp->hasResources())
+            return;
 
-    comp->releaseTexture();
+        comp->releaseTexture();
 
+        QQuickWindow *win = QQuickItem::window();
+        if (!win) {
+            qWarning("Failed to release graphics resources because QQuickWindow is not available.");
+            return;
+        }
+
+        QRhi *rhi = win->rhi();
+        if (!rhi) {
+            qWarning("Failed to release graphics resources because RHI is not available.");
+            return;
+        }
+
+        // Do not schedule clean-up if the resources were created on the current thread.
+        if (QThread::currentThread() == rhi->thread()) {
+            comp->releaseResources();
+            return;
+        }
+        // make sure we release compositor handle before
+    }
     QQuickWindow *win = QQuickItem::window();
-    if (!win) {
-        qWarning("Failed to release graphics resources because QQuickWindow is not available.");
-        return;
-    }
-
-    QRhi *rhi = win->rhi();
-    if (!rhi) {
-        qWarning("Failed to release graphics resources because RHI is not available.");
-        return;
-    }
-
-    // Do not schedule clean-up if the resources were created on the current thread.
-    if (QThread::currentThread() == rhi->thread()) {
-        comp->releaseResources();
-        return;
-    }
-
-    if (win->isExposed())
-        win->scheduleRenderJob(new CleanupJob(std::move(comp)), QQuickWindow::NoStage);
-    else {
+    if (win->isExposed()) {
+        CleanupJob *job = new CleanupJob(this);
+        win->scheduleRenderJob(job, QQuickWindow::NoStage);
+    } else {
         // TODO: Try to find a proper way to schedule job on the render thread if the window is
         // not exposed.
         // This is reproducible with ./tst_qquickwebengineviewgraphics simpleGraphics simpleGraphics
@@ -477,6 +499,11 @@ QSGNode *RenderWidgetHostViewQtDelegateItem::updatePaintNode(QSGNode *oldNode, U
     return node;
 }
 
+void RenderWidgetHostViewQtDelegateItem::updatePolish()
+{
+    m_client->visualPropertiesChanged();
+}
+
 void RenderWidgetHostViewQtDelegateItem::onBeforeRendering()
 {
     auto comp = compositor();
@@ -495,7 +522,7 @@ void RenderWidgetHostViewQtDelegateItem::onAfterFrameEnd()
 
 void RenderWidgetHostViewQtDelegateItem::onWindowPosChanged()
 {
-    m_client->visualPropertiesChanged();
+    polish();
 }
 
 void RenderWidgetHostViewQtDelegateItem::onHide()
