@@ -409,8 +409,6 @@ void QQuickWebEngineViewPrivate::contextMenuRequested(QWebEngineContextMenuReque
     m_contextMenuRequest = request;
 
     QQmlEngine *engine = qmlEngine(q);
-
-    // TODO: this is a workaround for QTBUG-65044
     if (!engine)
         return;
 
@@ -446,8 +444,14 @@ void QQuickWebEngineViewPrivate::contextMenuRequested(QWebEngineContextMenuReque
 void QQuickWebEngineViewPrivate::navigationRequested(int navigationType, const QUrl &url, bool &accepted, bool isMainFrame, bool hasFrameData)
 {
     Q_Q(QQuickWebEngineView);
+
+    QQmlEngine *engine = qmlEngine(q);
+    if (!engine)
+        return;
+
     auto request = new QWebEngineNavigationRequest(url, static_cast<QWebEngineNavigationRequest::NavigationType>(navigationType), isMainFrame, hasFrameData);
-    qmlEngine(q)->newQObject(request);
+
+    engine->newQObject(request);
     Q_EMIT q->navigationRequested(request);
 
     accepted = request->isAccepted();
@@ -458,9 +462,14 @@ void QQuickWebEngineViewPrivate::navigationRequested(int navigationType, const Q
 void QQuickWebEngineViewPrivate::javascriptDialog(QSharedPointer<JavaScriptDialogController> dialog)
 {
     Q_Q(QQuickWebEngineView);
+
+    QQmlEngine *engine = qmlEngine(q);
+    if (!engine)
+        return;
+
     QQuickWebEngineJavaScriptDialogRequest *request = new QQuickWebEngineJavaScriptDialogRequest(dialog);
     // mark the object for gc by creating temporary jsvalue
-    qmlEngine(q)->newQObject(request);
+    engine->newQObject(request);
     Q_EMIT q->javaScriptDialogRequested(request);
     if (!request->isAccepted())
         ui()->showDialog(dialog);
@@ -476,9 +485,14 @@ void QQuickWebEngineViewPrivate::selectClientCert(
         const QSharedPointer<QtWebEngineCore::ClientCertSelectController> &controller)
 {
     Q_Q(QQuickWebEngineView);
+
+    QQmlEngine *engine = qmlEngine(q);
+    if (!engine)
+        return;
+
     QQuickWebEngineClientCertificateSelection *certSelection = new QQuickWebEngineClientCertificateSelection(controller);
     // mark the object for gc by creating temporary jsvalue
-    qmlEngine(q)->newQObject(certSelection);
+    engine->newQObject(certSelection);
     Q_EMIT q->selectClientCertificate(certSelection);
 }
 
@@ -545,9 +559,14 @@ void QQuickWebEngineViewPrivate::runFeaturePermissionRequest(
 void QQuickWebEngineViewPrivate::showColorDialog(QSharedPointer<ColorChooserController> controller)
 {
     Q_Q(QQuickWebEngineView);
+
+    QQmlEngine *engine = qmlEngine(q);
+    if (!engine)
+        return;
+
     QQuickWebEngineColorDialogRequest *request = new QQuickWebEngineColorDialogRequest(controller);
     // mark the object for gc by creating temporary jsvalue
-    qmlEngine(q)->newQObject(request);
+    engine->newQObject(request);
     Q_EMIT q->colorDialogRequested(request);
     if (!request->isAccepted())
         ui()->showColorDialog(controller);
@@ -556,9 +575,14 @@ void QQuickWebEngineViewPrivate::showColorDialog(QSharedPointer<ColorChooserCont
 void QQuickWebEngineViewPrivate::runFileChooser(QSharedPointer<FilePickerController> controller)
 {
     Q_Q(QQuickWebEngineView);
+
+    QQmlEngine *engine = qmlEngine(q);
+    if (!engine)
+        return;
+
     QQuickWebEngineFileDialogRequest *request = new QQuickWebEngineFileDialogRequest(controller);
     // mark the object for gc by creating temporary jsvalue
-    qmlEngine(q)->newQObject(request);
+    engine->newQObject(request);
     Q_EMIT q->fileDialogRequested(request);
     if (!request->isAccepted())
         ui()->showFilePicker(controller);
@@ -804,9 +828,14 @@ void QQuickWebEngineViewPrivate::javaScriptConsoleMessage(JavaScriptConsoleMessa
 void QQuickWebEngineViewPrivate::authenticationRequired(QSharedPointer<AuthenticationDialogController> controller)
 {
     Q_Q(QQuickWebEngineView);
+
+    QQmlEngine *engine = qmlEngine(q);
+    if (!engine)
+        return;
+
     QQuickWebEngineAuthenticationDialogRequest *request = new QQuickWebEngineAuthenticationDialogRequest(controller);
     // mark the object for gc by creating temporary jsvalue
-    qmlEngine(q)->newQObject(request);
+    engine->newQObject(request);
     Q_EMIT q->authenticationDialogRequested(request);
     if (!request->isAccepted())
         ui()->showDialog(controller);
@@ -1388,9 +1417,14 @@ bool QQuickWebEngineViewPrivate::isEnabled() const
 void QQuickWebEngineViewPrivate::setToolTip(const QString &toolTipText)
 {
     Q_Q(QQuickWebEngineView);
+
+    QQmlEngine *engine = qmlEngine(q);
+    if (!engine)
+        return;
+
     QQuickWebEngineTooltipRequest *request = new QQuickWebEngineTooltipRequest(toolTipText, q);
     // mark the object for gc by creating temporary jsvalue
-    qmlEngine(q)->newQObject(request);
+    engine->newQObject(request);
     Q_EMIT q->tooltipRequested(request);
     if (!request->isAccepted())
         ui()->showToolTip(toolTipText);
@@ -1435,13 +1469,17 @@ void QQuickWebEngineViewPrivate::showTouchSelectionMenu(QtWebEngineCore::TouchSe
     Q_UNUSED(handleSize);
     Q_Q(QQuickWebEngineView);
 
+    QQmlEngine *engine = qmlEngine(q);
+    if (!engine)
+        return;
+
     const int kSpacingBetweenButtons = 2;
     const int kMenuButtonMinWidth = 63;
     const int kMenuButtonMinHeight = 38;
 
     QQuickWebEngineTouchSelectionMenuRequest *request = new QQuickWebEngineTouchSelectionMenuRequest(
                 selectionBounds, menuController);
-    qmlEngine(q)->newQObject(request);
+    engine->newQObject(request);
     Q_EMIT q->touchSelectionMenuRequested(request);
 
     if (request->isAccepted()) {
@@ -1847,19 +1885,47 @@ void QQuickWebEngineView::geometryChange(const QRectF &newGeometry, const QRectF
 {
     QQuickItem::geometryChange(newGeometry, oldGeometry);
     Q_D(QQuickWebEngineView);
-    if (d->delegateItem)
+    if (d->delegateItem) {
         d->delegateItem->setSize(newGeometry.size());
+        // this handles notifications of local offset changes
+        d->delegateItem->polish();
+    }
 }
 
 void QQuickWebEngineView::itemChange(ItemChange change, const ItemChangeData &value)
 {
-    Q_D(QQuickWebEngineView);
-    if (d && d->profileInitialized() && d->adapter->isInitialized()
+    QQuickItem::itemChange(change, value);
+    if (!d_ptr) // see releaseProfile()
+        return;
+    if (d_ptr->profileInitialized() && d_ptr->adapter->isInitialized()
             && (change == ItemSceneChange || change == ItemVisibleHasChanged)) {
         if (window())
-            d->adapter->setVisible(isVisible());
+            d_ptr->adapter->setVisible(isVisible());
+    }
+    if (change == ItemParentHasChanged) {
+        // track global offset changes
+        QQuickItem *item = value.item;
+        // detach
+        while (item) {
+            disconnect(item, nullptr, this, nullptr);
+            item = item->parentItem();
+        }
+        // attach
+        item = parentItem();
+        while (item) {
+            connect(item, &QQuickItem::xChanged, this, [this]() {
+                if (d_ptr && d_ptr->delegateItem)
+                    d_ptr->delegateItem->polish();
+            });
+            connect(item, &QQuickItem::yChanged, this, [this]() {
+                if (d_ptr && d_ptr->delegateItem)
+                    d_ptr->delegateItem->polish();
+            });
+            item = item->parentItem();
+        }
+        if (d_ptr->delegateItem)
+            d_ptr->delegateItem->polish();
     }
-    QQuickItem::itemChange(change, value);
 }
 
 void QQuickWebEngineView::acceptAsNewWindow(QWebEngineNewWindowRequest *request)
